@@ -46,7 +46,8 @@ int main(int argc,char **argv)
     printf("1.Create A G.A.N.N And Teach It\n");
     printf("2.Run An Existing G.A.N.N From GKDB\n");
     printf("3.Create A G.A.N.N - Teach It And Run It\n");
-    printf("4.Exit\n");
+    printf("4.Remove Registrations From GKDB\n");
+    printf("5.Exit\n");
     printf("Choice:");
     
     scanf("%i",&i);
@@ -67,7 +68,6 @@ int main(int argc,char **argv)
         GDMLoader();
         
         printf("Done!\n\n");
-        printf("Starting Simulation...\n\n");
         
         //Simulate G.A.N.N At Learning Mode
         GNMS(0);
@@ -96,7 +96,6 @@ int main(int argc,char **argv)
         GDMLoader();
         
         printf("Done!\n\n");
-        printf("Starting Simulation...\n\n");
         
         //Simulate G.A.N.N At Learning Mode
         GNMS(0);
@@ -108,6 +107,32 @@ int main(int argc,char **argv)
     
     else if (i==4)
     
+    {
+    
+        printf("Please Specify The Registration You Want To Remove\n");
+        printf("(Registration Number Must Be Between 1-%i)\n",MAX_REG);
+        printf("Choice:");
+        
+        scanf("%i",&i);
+        
+        if (i<1 OR i>MAX_REG)
+        
+        {
+        
+            printf("Error: Wrong Registration Number!\n");
+            
+            exit(1);
+        
+        }
+        
+        GRemData(i);
+        
+        printf("Done!\n");
+    
+    }
+    
+    else if (i==5)
+    
     {
     
         printf("Thank You For Using G.A.N.N\n");
