@@ -159,7 +159,7 @@ void GDMLoader()
     
     //Read Starting Header
     fscanf(FileToOpen,"%i\n%i\n%i\n%i\n%i\n%i\n%f\n%i\n",\
-    &SimNum,&ECT,&GMSType,&GMCType,&Inputs,&Outputs,&Threshold,&Layers);
+    &SimNum,&ECT,&GMSType,&GMCType,&Inputs,&Outputs,&LearnTH,&Layers);
     
     //Get GNeurons From Layers
     for (i=0;i<Layers;i++)
