@@ -34,7 +34,7 @@ float GGenData(int FuncType,float Val)
     GRand();
     
     //Check Function Type (0:Binary,1:Real)
-    if (FuncType==0 && Val==0.0)
+    if (FuncType==0 AND Val==0.0)
     
     {
     
