@@ -44,7 +44,7 @@ GSocket::~GSocket()
 {
 
     //Unload Pins Matrix
-    delete [] Pins;
+    delete []Pins;
 
 }
 
@@ -56,7 +56,7 @@ void GSocket::SetST(int SType)
 {
 
     //Check Socket Type (0:Input,1:Output)
-    if (SType<0 || SType>1)
+    if (SType<0 OR SType>1)
     
     {
     
@@ -78,7 +78,7 @@ void GSocket::SetPins(int Num)
 {
 
     //Check Socket Pins (Not Less Than 1 Or Not More Than MAX_PIN)
-    if (Num<1 || Num>MAX_PIN)
+    if (Num<1 OR Num>MAX_PIN)
     
     {
     
@@ -100,7 +100,7 @@ void GSocket::SetPT(int Pin,int PinType)
 {
 
     //Check Socket Pins
-    if (Pin<0 || Pin>SockPins)
+    if (Pin<0 OR Pin>SockPins)
     
     {
     
@@ -111,7 +111,7 @@ void GSocket::SetPT(int Pin,int PinType)
     }
     
     //Socket Pin Type (0:Binary,1:Real)
-    if (PinType<0 || PinType>1)
+    if (PinType<0 OR PinType>1)
     
     {
     
@@ -133,7 +133,7 @@ void GSocket::SetPS(int Pin,int PinState)
 {
 
     //Check Socket Pins
-    if (Pin<0 || Pin>SockPins)
+    if (Pin<0 OR Pin>SockPins)
     
     {
     
@@ -144,7 +144,7 @@ void GSocket::SetPS(int Pin,int PinState)
     }
     
     //Socket Pin State (0:Off,1:On)
-    if (PinState<0 || PinState>1)
+    if (PinState<0 OR PinState>1)
     
     {
     
@@ -166,7 +166,7 @@ void GSocket::SetPV(int Pin,float Val)
 {
 
     //Check Socket Pins And Values
-    if (Pin<0 || Pin>SockPins)
+    if (Pin<0 OR Pin>SockPins)
     
     {
     
@@ -199,7 +199,7 @@ void GSocket::SetPV(int Pin,float Val1,float Val2)
 {
 
     //Check Socket Pins And Values
-    if (Pin<0 || Pin>SockPins)
+    if (Pin<0 OR Pin>SockPins)
     
     {
     
@@ -263,7 +263,7 @@ int GSocket::GetPT(int Pin)
 
 {
 
-    if (Pin<0 || Pin>SockPins)
+    if (Pin<0 OR Pin>SockPins)
     
     {
     
@@ -284,7 +284,7 @@ int GSocket::GetPS(int Pin)
 
 {
 
-    if (Pin<0 || Pin>SockPins)
+    if (Pin<0 OR Pin>SockPins)
     
     {
     
@@ -305,7 +305,7 @@ float GSocket::GetPV(int Pin,int Choice)
 
 {
 
-    if (Pin<0 || Pin>SockPins)
+    if (Pin<0 OR Pin>SockPins)
     
     {
     
