@@ -183,16 +183,13 @@ float GErrStat(float *FirstData,float *LastData,int StatType);
 //Geeks Error Correction (Function)
 void GErrC(GNeuron *GMatrix,int GNIndex,float Err,int CheckType);
 
-//Geeks Runtime Manager Console
-int GRMC();
-
 //Geeks [I/O] Distribution And Map Loader (Function)
 void GDMLoader();
 
 //Geeks Generate Data (Function)
 float GGenData(int FuncType,float Val);
 
-//Geeks Generate Data (Function) [Over-Loaded]
+//Geeks Generate Data (Function) [Overloaded]
 float GGenData(float Val1,float Val2);
 
 //Geeks Read Data (Function)
@@ -202,16 +199,16 @@ void GReadData(GNeuron *GMatrix,int RegNum);
 void GSaveData(GNeuron *GMatrix);
 
 //Geeks Remove Data (Function)
-void GRemData(GNeuron *GMatrix,int RegNum);
+void GRemData(int RegNum);
 
 //Geeks Socket And Neural Map Creator (Function)
 void GSNMC();
 
-//Geeks Neural Map Simulator
+//Geeks Neural Map Simulator (Function)
 void GNMS(int SimFunc);
 
-//Geeks Unified Messaging System (Function)
-void GUMsgS(int MsgType,int MsgNum);
+//Geeks Runtime Manager Console (Function)
+int GRMC();
 
 GSocket InSocket;		//Inputs GSocket
 GSocket OutSocket;		//Outputs GSocket
